@@ -283,6 +283,17 @@ void KateConsole::showEvent(QShowEvent *)
     loadConsoleIfNeeded();
 }
 
+static constexpr QChar eolChar()
+{
+    // On windows, if the shell is powershell
+    // '\r' needs to be sent to trigger enter
+#ifdef Q_OS_WIN
+    return QLatin1Char('\r');
+#else
+    return QLatin1Char('\n');
+#endif
+}
+
 void KateConsole::cd(const QString &path)
 {
     if (m_currentPath == path) {
@@ -294,7 +305,7 @@ void KateConsole::cd(const QString &path)
     }
 
     m_currentPath = path;
-    QString command = QLatin1String(" cd ") + KShell::quoteArg(m_currentPath) + QLatin1Char('\n');
+    QString command = QLatin1String(" cd ") + KShell::quoteArg(m_currentPath) + eolChar();
 
     // special handling for some interpreters
     TerminalInterface *t = qobject_cast<TerminalInterface *>(m_part);
@@ -435,7 +446,7 @@ void KateConsole::slotRun()
     }
 
     // then filename
-    QFileInfo fileInfo(url.path());
+    QFileInfo fileInfo(url.toLocalFile());
     const bool removeExt = cg.readEntry("RemoveExtension", true);
     // append filename without extension (i.e. keep only the basename)
     const QString path = fileInfo.absolutePath() + QLatin1Char('/') + (removeExt ? fileInfo.baseName() : fileInfo.fileName());
@@ -457,7 +468,7 @@ void KateConsole::slotRun()
         return;
     }
     // echo to terminal
-    sendInput(output_str + QLatin1Char('\n'));
+    sendInput(output_str + eolChar());
 }
 
 void KateConsole::slotToggleVisibility()
