@@ -6,8 +6,8 @@
 
 #include "lspclientserver.h"
 
-#include "lspclient_debug.h"
 #include "hostprocess.h"
+#include "lspclient_debug.h"
 
 #include <QCoreApplication>
 #include <QFileInfo>
@@ -688,9 +688,6 @@ static QList<LSPCompletionItem> parseDocumentCompletion(const QJsonValue &result
             sortText = label;
         }
         auto insertText = item.value(QStringLiteral("insertText")).toString();
-        if (insertText.isEmpty()) {
-            insertText = label;
-        }
         LSPTextEdit lspTextEdit;
         const auto &textEdit = item.value(QStringLiteral("textEdit")).toObject();
         if (!textEdit.empty()) {
@@ -705,6 +702,10 @@ static QList<LSPCompletionItem> parseDocumentCompletion(const QJsonValue &result
             lspTextEdit.newText = newText;
             lspTextEdit.range = parseRange(textEdit.value(QStringLiteral("range")).toObject());
         }
+        if (insertText.isEmpty()) {
+            // if this happens, the server is broken but lets try the label anyways
+            insertText = label;
+        }
         auto kind = static_cast<LSPCompletionItemKind>(item.value(MEMBER_KIND).toInt());
         const auto additionalTextEdits = parseTextEdit(item.value(QStringLiteral("additionalTextEdits")));
 
@@ -929,12 +930,20 @@ static QVector<LSPInlayHint> parseInlayHints(const QJsonValue &result)
     QVector<LSPInlayHint> ret;
     for (const auto &hint : hints) {
         LSPInlayHint h;
-        const auto &label = hint[QStringLiteral("label")];
-        if (label.isObject()) {
-            h.label = label.toObject().value(QStringLiteral("value")).toString();
+        const auto label = hint[QStringLiteral("label")];
+        if (label.isArray()) {
+            auto labelPartArray = label.toArray();
+            for (const auto &part : labelPartArray) {
+                h.label += part.toObject().value(QStringLiteral("value")).toString();
+            }
         } else {
             h.label = label.toString();
         }
+        // skip if empty
+        if (h.label.isEmpty()) {
+            continue;
+        }
+
         h.position = parsePosition(hint[QStringLiteral("position")].toObject());
         h.paddingLeft = hint[QStringLiteral("paddingLeft")].toBool();
         h.paddingRight = hint[QStringLiteral("paddingRight")].toBool();
