@@ -5,6 +5,7 @@
 */
 #pragma once
 
+#include <QSet>
 #include <QString>
 #include <QVector>
 
@@ -61,6 +62,7 @@ struct GitParsedStatus {
     QVector<StatusItem> unmerge;
     QVector<StatusItem> staged;
     QVector<StatusItem> changed;
+    QSet<QString> nonUniqueFileNames;
 };
 
 GitParsedStatus parseStatus(const QByteArray &raw, bool withNumStat, const QString &workingDir);
