@@ -6,6 +6,7 @@
 #pragma once
 
 #include <QAbstractItemModel>
+#include <QSet>
 
 #include "git/gitstatus.h"
 
@@ -56,5 +57,6 @@ public:
 
 private:
     QVector<GitUtils::StatusItem> m_nodes[4];
+    QSet<QString> m_nonUniqueFileNames;
     bool m_showNumStat = false;
 };
