@@ -8,11 +8,15 @@
 #include "kateprojectinfoviewterminal.h"
 #include "kateprojectpluginview.h"
 
+#include <KActionCollection>
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <KSharedConfig>
 #include <KShell>
+#include <KTextEditor/MainWindow>
+#include <KXMLGUIClient>
+#include <KXMLGUIFactory>
 #include <kde_terminal_interface.h>
 #include <ktexteditor_utils.h>
 
@@ -23,7 +27,6 @@ KPluginFactory *KateProjectInfoViewTerminal::s_pluginFactory = nullptr;
 KateProjectInfoViewTerminal::KateProjectInfoViewTerminal(KateProjectPluginView *pluginView, const QString &directory)
     : m_pluginView(pluginView)
     , m_directory(directory)
-    , m_konsolePart(nullptr)
 {
     /**
      * layout widget
@@ -65,53 +68,55 @@ void KateProjectInfoViewTerminal::showEvent(QShowEvent *)
 
 void KateProjectInfoViewTerminal::loadTerminal()
 {
-    /**
-     * null in any case, if loadTerminal fails below and we are in the destroyed event
-     */
-    m_konsolePart = nullptr;
-    setFocusProxy(nullptr);
+    if (hasKonsole()) {
+        /**
+         * null in any case, if loadTerminal fails below and we are in the destroyed event
+         */
+        m_konsolePart = nullptr;
+        setFocusProxy(nullptr);
 
-    /**
-     * we shall not arrive here without a factory, if it is not there, no terminal toolview shall be created
-     */
-    Q_ASSERT(pluginFactory());
+        /**
+         * we shall not arrive here without a factory, if it is not there, no terminal toolview shall be created
+         */
+        Q_ASSERT(pluginFactory());
 
-    /**
-     * create part
-     */
-    m_konsolePart = pluginFactory()->create<KParts::ReadOnlyPart>(this);
-    if (!m_konsolePart) {
-        return;
+        /**
+         * create part
+         */
+        m_konsolePart = pluginFactory()->create<KParts::ReadOnlyPart>(this);
+        if (!m_konsolePart) {
+            return;
+        }
+
+        /**
+         * init locale translation stuff
+         */
+        // FIXME KF5 KGlobal::locale()->insertCatalog("konsole");
+
+        /**
+         * switch to right directory
+         */
+        qobject_cast<TerminalInterface *>(m_konsolePart)->showShellInDir(m_directory);
+
+        /**
+         * add to widget
+         */
+        if (auto konsoleTabWidget = qobject_cast<QTabWidget *>(m_konsolePart->widget())) {
+            konsoleTabWidget->setTabBarAutoHide(true);
+            konsoleTabWidget->installEventFilter(this);
+        }
+        m_layout->addWidget(m_konsolePart->widget());
+
+        setFocusProxy(m_konsolePart->widget());
+
+        /**
+         * guard destruction, create new terminal!
+         */
+        connect(m_konsolePart, &KParts::ReadOnlyPart::destroyed, this, &KateProjectInfoViewTerminal::loadTerminal);
+        // clang-format off
+        connect(m_konsolePart, SIGNAL(overrideShortcut(QKeyEvent*,bool&)), this, SLOT(overrideShortcut(QKeyEvent*,bool&)));
+        // clang-format on
     }
-
-    /**
-     * init locale translation stuff
-     */
-    // FIXME KF5 KGlobal::locale()->insertCatalog("konsole");
-
-    /**
-     * switch to right directory
-     */
-    qobject_cast<TerminalInterface *>(m_konsolePart)->showShellInDir(m_directory);
-
-    /**
-     * add to widget
-     */
-    if (auto konsoleTabWidget = qobject_cast<QTabWidget *>(m_konsolePart->widget())) {
-        konsoleTabWidget->setTabBarAutoHide(true);
-        konsoleTabWidget->installEventFilter(this);
-    }
-    m_layout->addWidget(m_konsolePart->widget());
-
-    setFocusProxy(m_konsolePart->widget());
-
-    /**
-     * guard destruction, create new terminal!
-     */
-    connect(m_konsolePart, &KParts::ReadOnlyPart::destroyed, this, &KateProjectInfoViewTerminal::loadTerminal);
-    // clang-format off
-    connect(m_konsolePart, SIGNAL(overrideShortcut(QKeyEvent*,bool&)), this, SLOT(overrideShortcut(QKeyEvent*,bool&)));
-    // clang-format on
 }
 
 void KateProjectInfoViewTerminal::overrideShortcut(QKeyEvent *keyEvent, bool &override)
@@ -158,9 +163,9 @@ void KateProjectInfoViewTerminal::respawn(const QString &directory)
     }
 
     m_directory = directory;
-    disconnect(m_konsolePart, &KParts::ReadOnlyPart::destroyed, this, &KateProjectInfoViewTerminal::loadTerminal);
 
-    if (m_konsolePart != nullptr) {
+    if (m_konsolePart) {
+        disconnect(m_konsolePart, &KParts::ReadOnlyPart::destroyed, this, &KateProjectInfoViewTerminal::loadTerminal);
         delete m_konsolePart;
     }
 
@@ -195,10 +200,10 @@ bool KateProjectInfoViewTerminal::eventFilter(QObject *w, QEvent *e)
 
 void KateProjectInfoViewTerminal::runCommand(const QString &workingDir, const QString &cmd)
 {
-    auto terminal = qobject_cast<TerminalInterface *>(m_konsolePart);
-    if (!terminal) {
+    if (!m_konsolePart) {
         loadTerminal();
     }
+    auto terminal = qobject_cast<TerminalInterface *>(m_konsolePart);
     terminal->sendInput(QStringLiteral("\x05\x15"));
     const QString changeDirCmd = QStringLiteral("cd ") + KShell::quoteArg(workingDir) + QStringLiteral("\n");
     terminal->sendInput(changeDirCmd);
