@@ -334,13 +334,15 @@ void DiagnosticsView::registerDiagnosticsProvider(DiagnosticsProvider *provider)
     connect(provider, &DiagnosticsProvider::fixesAvailable, this, &DiagnosticsView::onFixesAvailable);
     connect(provider, &DiagnosticsProvider::requestClearDiagnostics, this, &DiagnosticsView::clearDiagnosticsFromProvider);
     connect(provider, &DiagnosticsProvider::requestClearSuppressions, this, &DiagnosticsView::clearSuppressionsFromProvider);
+    connect(provider, &QObject::destroyed, this, [this](QObject *o) {
+        unregisterDiagnosticsProvider(static_cast<DiagnosticsProvider *>(o));
+    });
     m_providers.push_back(provider);
 }
 
 void DiagnosticsView::unregisterDiagnosticsProvider(DiagnosticsProvider *provider)
 {
     if (!m_providers.contains(provider)) {
-        qWarning() << provider << "not registred but trying to unregister!";
         return;
     }
     disconnect(provider, &DiagnosticsProvider::diagnosticsAdded, this, &DiagnosticsView::onDiagnosticsAdded);
@@ -348,6 +350,8 @@ void DiagnosticsView::unregisterDiagnosticsProvider(DiagnosticsProvider *provide
     disconnect(provider, &DiagnosticsProvider::requestClearDiagnostics, this, &DiagnosticsView::clearDiagnosticsFromProvider);
     disconnect(provider, &DiagnosticsProvider::requestClearSuppressions, this, &DiagnosticsView::clearSuppressionsFromProvider);
     m_providers.removeOne(provider);
+
+    clearDiagnosticsFromProvider(provider);
 }
 
 void DiagnosticsView::readSessionConfig(const KConfigGroup &config)
