@@ -14,14 +14,28 @@
 #include <KAboutData>
 #include <KConfigGui>
 #include <KCrash>
+#include <KLazyLocalizedString>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KNetworkMounts>
 #include <KSharedConfig>
+
+// X11 startup handling
+#if __has_include(<KStartupInfo>)
 #include <KStartupInfo>
+#endif
+
 #include <KWindowInfo>
 
 #ifdef WITH_KUSERFEEDBACK
+#ifdef USE_KUSERFEEDBACK_QT6
+#include <KUserFeedbackQt6/ApplicationVersionSource>
+#include <KUserFeedbackQt6/PlatformInfoSource>
+#include <KUserFeedbackQt6/QtVersionSource>
+#include <KUserFeedbackQt6/ScreenInfoSource>
+#include <KUserFeedbackQt6/StartCountSource>
+#include <KUserFeedbackQt6/UsageTimeSource>
+#else
 #include <KUserFeedback/ApplicationVersionSource>
 #include <KUserFeedback/PlatformInfoSource>
 #include <KUserFeedback/QtVersionSource>
@@ -29,6 +43,7 @@
 #include <KUserFeedback/StartCountSource>
 #include <KUserFeedback/UsageTimeSource>
 #endif
+#endif
 
 #include <QApplication>
 #include <QCommandLineParser>
@@ -46,6 +61,34 @@
 #include <signal_watcher.h>
 #include <urlinfo.h>
 
+#ifndef Q_OS_WIN
+#include <unistd.h>
+#ifndef Q_OS_HAIKU
+#include <libintl.h>
+#endif
+#endif
+
+#include <iostream>
+
+#ifdef Q_OS_WIN
+#include <windows.h>
+#endif
+
+#ifdef HAVE_CTERMID
+#include <fcntl.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <termios.h>
+#include <unistd.h>
+#endif
+
+#if HAVE_DAEMON
+#include <unistd.h>
+#endif
+
+// remember if we were started inside a terminal
+static bool insideTerminal = false;
+
 /**
  * singleton instance pointer
  */
@@ -53,6 +96,100 @@ static KateApp *appSelf = Q_NULLPTR;
 
 Q_LOGGING_CATEGORY(LOG_KATE, "kate", QtWarningMsg)
 
+void KateApp::initPreApplicationCreation(bool detach)
+{
+#if !defined(Q_OS_WIN) && !defined(Q_OS_HAIKU)
+    // Prohibit using sudo or kdesu (but allow using the root user directly)
+    if (getuid() == 0) {
+        setlocale(LC_ALL, "");
+        bindtextdomain("kate", KDE_INSTALL_FULL_LOCALEDIR);
+        if (!qEnvironmentVariableIsEmpty("SUDO_USER")) {
+            auto message = kli18n(
+                "Running this editor with sudo can cause bugs and expose you to security vulnerabilities. "
+                "Instead use this editor normally and you will be prompted for elevated privileges when "
+                "saving documents if needed.");
+            std::cout << dgettext("kate", message.untranslatedText()) << std::endl;
+            exit(EXIT_FAILURE);
+        } else if (!qEnvironmentVariableIsEmpty("KDESU_USER")) {
+            auto message = kli18n(
+                "Running this editor with kdesu can cause bugs and expose you to security vulnerabilities. "
+                "Instead use this editor normally and you will be prompted for elevated privileges when "
+                "saving documents if needed.");
+            std::cout << dgettext("kate", message.untranslatedText()) << std::endl;
+            exit(EXIT_FAILURE);
+        }
+    }
+#endif
+
+    /**
+     * enable dark mode for title bar on Windows
+     */
+#if defined(Q_OS_WIN)
+    if (!qEnvironmentVariableIsSet("QT_QPA_PLATFORM")) {
+        qputenv("QT_QPA_PLATFORM", "windows:darkmode=1");
+    }
+#endif
+
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+    /**
+     * enable high dpi support
+     */
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+#endif
+
+    /**
+     * allow fractional scaling
+     * we only activate this on Windows, it seems to creates problems on unices
+     * (and there the fractional scaling with the QT_... env vars as set by KScreen works)
+     * see bug 416078
+     *
+     * we switched to Qt::HighDpiScaleFactorRoundingPolicy::RoundPreferFloor because of font rendering issues
+     * we follow what Krita does here, see https://invent.kde.org/graphics/krita/-/blob/master/krita/main.cc
+     * we raise the Qt requirement to  5.15 as it seems some patches went in after 5.14 that are needed
+     * see Krita comments, too
+     */
+#if defined(Q_OS_WIN)
+    QGuiApplication::setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy::RoundPreferFloor);
+#endif
+
+#ifdef Q_OS_WIN
+    // Enable on windows to see output in console
+    if (AttachConsole(ATTACH_PARENT_PROCESS)) {
+        // we are inside a terminal
+        insideTerminal = true;
+
+        // don't enable output if we shall detach, to avoid terminal pollution
+        if (!detach) {
+            if (fileno(stdout) < 0)
+                freopen("CON", "w", stdout);
+            if (fileno(stderr) < 0)
+                freopen("CON", "w", stderr);
+        }
+    }
+#endif
+
+#ifdef HAVE_CTERMID
+    /**
+     * https://stackoverflow.com/questions/1312922/detect-if-stdin-is-a-terminal-or-pipe-in-c-c-qt
+     */
+    char tty[L_ctermid + 1] = {0};
+    ctermid(tty);
+    if (int fd = ::open(tty, O_RDONLY); fd >= 0) {
+        insideTerminal = true;
+        ::close(fd);
+    }
+#endif
+
+#ifdef HAVE_DAEMON
+    if (detach) {
+        // just try it, if it doesn't work we just continue in the foreground
+        const int ret = daemon(1, 0 /* close in and outputs to avoid pollution of shell */);
+        (void)ret;
+    }
+#endif
+}
+
 KateApp::KateApp(const QCommandLineParser &args, const ApplicationMode mode, const QString &sessionsDir)
     : m_args(args)
     , m_mode(mode)
@@ -267,8 +404,11 @@ bool KateApp::startupKate()
         } else if (!m_args.isSet(QStringLiteral("stdin")) && (m_args.positionalArguments().count() == 0)) { // only start session if no files specified
             // let the user choose session if possible
             if (!sessionManager()->chooseSession()) {
+#if __has_include(<KStartupInfo>)
                 // we will exit kate now, notify the rest of the world we are done
-                KStartupInfo::appStarted(KStartupInfo::startupId());
+                KStartupInfo::appStarted();
+#endif
+
                 return false;
             }
         } else {
@@ -281,11 +421,6 @@ bool KateApp::startupKate()
         newMainWindow();
     }
 
-    // notify about start
-    QWidget *win = activeKateMainWindow();
-    win->setAttribute(Qt::WA_NativeWindow, true);
-    KStartupInfo::setNewStartupId(win->windowHandle(), KStartupInfo::startupId());
-
     QTextCodec *codec = m_args.isSet(QStringLiteral("encoding")) ? QTextCodec::codecForName(m_args.value(QStringLiteral("encoding")).toUtf8()) : nullptr;
     bool tempfileSet = m_args.isSet(QStringLiteral("tempfile"));
 
@@ -522,12 +657,12 @@ bool KateApp::openInput(const QString &text, const QString &encoding)
     return doc->setText(text);
 }
 
-KateMainWindow *KateApp::newMainWindow(KConfig *sconfig_, const QString &sgroup_)
+KateMainWindow *KateApp::newMainWindow(KConfig *sconfig_, const QString &sgroup_, bool userTriggered)
 {
     KConfig *sconfig = sconfig_ ? sconfig_ : KSharedConfig::openConfig().data();
     QString sgroup = !sgroup_.isEmpty() ? sgroup_ : QStringLiteral("MainWindow0");
 
-    KateMainWindow *mainWindow = new KateMainWindow(sconfig, sgroup);
+    KateMainWindow *mainWindow = new KateMainWindow(sconfig, sgroup, userTriggered);
     mainWindow->show();
 
     return mainWindow;
@@ -667,3 +802,8 @@ bool KateApp::documentVisibleInOtherWindows(KTextEditor::Document *doc, KateMain
     }
     return false;
 }
+
+bool KateApp::isInsideTerminal()
+{
+    return insideTerminal;
+}
