@@ -38,31 +38,28 @@ void KateStashManager::clearStashForSession(const KateSession::Ptr session)
     }
 }
 
-void KateStashManager::stashDocuments(KConfig *config, const QList<KTextEditor::Document *> &documents)
+void KateStashManager::stashDocuments(KConfig *config, const QList<KTextEditor::Document *> &documents) const
 {
+    if (!canStash()) {
+        return;
+    }
+
     // prepare stash directory
     const QString appDataPath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
     QDir dir(appDataPath);
     dir.mkdir(QStringLiteral("stash"));
     dir.cd(QStringLiteral("stash"));
 
-    const auto activeSession = KateApp::self()->sessionManager()->activeSession();
-    if (!activeSession || activeSession->isAnonymous() || activeSession->name().isEmpty()) {
-        qDebug(LOG_KATE) << "Could not stash files without a session";
-        return;
-    }
-
-    const QString sessionName = activeSession->name();
+    const QString sessionName = KateApp::self()->sessionManager()->activeSession()->name();
     dir.mkdir(sessionName);
     dir.cd(sessionName);
 
     int i = 0;
     for (KTextEditor::Document *doc : documents) {
-        const QString entryName = QStringLiteral("Document %1").arg(i);
-        KConfigGroup cg(config, entryName);
-
         // stash the file content
         if (doc->isModified()) {
+            const QString entryName = QStringLiteral("Document %1").arg(i);
+            KConfigGroup cg(config, entryName);
             stashDocument(doc, entryName, cg, dir.path());
         }
 
@@ -72,17 +69,15 @@ void KateStashManager::stashDocuments(KConfig *config, const QList<KTextEditor::
 
 bool KateStashManager::willStashDoc(KTextEditor::Document *doc) const
 {
-    const auto activeSession = KateApp::self()->sessionManager()->activeSession();
-    if (!activeSession || activeSession->isAnonymous() || activeSession->name().isEmpty()) {
-        return false;
-    }
-    if (doc->text().isEmpty()) {
+    Q_ASSERT(canStash());
+
+    if (doc->isEmpty()) {
         return false;
     }
     if (doc->url().isEmpty()) {
         return m_stashNewUnsavedFiles;
     }
-    if (doc->url().isLocalFile()) {
+    if (doc->isModified() && doc->url().isLocalFile()) {
         const QString path = doc->url().toLocalFile();
         if (path.startsWith(QDir::tempPath())) {
             return false; // inside tmp resource, do not stash
@@ -92,7 +87,7 @@ bool KateStashManager::willStashDoc(KTextEditor::Document *doc) const
     return false;
 }
 
-void KateStashManager::stashDocument(KTextEditor::Document *doc, const QString &stashfileName, KConfigGroup &kconfig, const QString &path)
+void KateStashManager::stashDocument(KTextEditor::Document *doc, const QString &stashfileName, KConfigGroup &kconfig, const QString &path) const
 {
     if (!willStashDoc(doc)) {
         return;
@@ -116,16 +111,22 @@ void KateStashManager::stashDocument(KTextEditor::Document *doc, const QString &
     kconfig.sync();
 }
 
-bool KateStashManager::popDocument(KTextEditor::Document *doc, const KConfigGroup &kconfig)
+bool KateStashManager::canStash() const
+{
+    const auto activeSession = KateApp::self()->sessionManager()->activeSession();
+    return activeSession && !activeSession->isAnonymous() && !activeSession->name().isEmpty();
+}
+
+void KateStashManager::popDocument(KTextEditor::Document *doc, const KConfigGroup &kconfig)
 {
     if (!(kconfig.hasKey("stashedFile"))) {
-        return false;
+        return;
     }
     qCDebug(LOG_KATE) << "popping stashed document" << doc->url();
 
     // read metadata
-    auto stashedFile = kconfig.readEntry("stashedFile");
-    auto url = QUrl(kconfig.readEntry("URL"));
+    const auto stashedFile = kconfig.readEntry("stashedFile");
+    const auto url = QUrl(kconfig.readEntry("URL"));
 
     bool checksumOk = true;
     if (url.isValid()) {
@@ -150,9 +151,5 @@ bool KateStashManager::popDocument(KTextEditor::Document *doc, const KConfigGrou
         if (!input.remove()) {
             qCWarning(LOG_KATE) << "Could not remove stash file" << stashedFile;
         }
-
-        return true;
-    } else {
-        return false;
     }
 }
