@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    SPDX-FileCopyrightText: 2001 Christoph Cullmann <cullmann@kde.org>
-   SPDX-FileCopyrightText: 2001 Joseph Wenninger <jowenn@kde.org>
+   // SPDX-FileCopyrightText: 2001 Joseph Wenninger <jowenn@kde.org>
    SPDX-FileCopyrightText: 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>
 
    SPDX-License-Identifier: LGPL-2.0-only
@@ -12,16 +12,15 @@
 #include "kateapp.h"
 #include "katemainwindow.h"
 #include "kateupdatedisabler.h"
-#include "kateviewspace.h"
-#include <kwidgetsaddons_version.h>
 #include "welcomeview/welcomeview.h"
+#include <kwidgetsaddons_version.h>
 
 #include <KTextEditor/Attribute>
 #include <KTextEditor/Document>
 #include <KTextEditor/View>
 
-#include <KActionCollection>
 #include <KAboutData>
+#include <KActionCollection>
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
@@ -29,7 +28,6 @@
 #include <KSharedConfig>
 #include <KToolBar>
 #include <KXMLGUIFactory>
-#include <kwidgetsaddons_version.h>
 
 #ifdef KF5Activities_FOUND
 #include <KActivities/ResourceInstance>
@@ -49,6 +47,8 @@ KateViewManager::KateViewManager(QWidget *parentW, KateMainWindow *parent)
     , m_minAge(0)
     , m_guiMergedView(nullptr)
 {
+    setObjectName(QStringLiteral("KateViewManager"));
+
     // we don't allow full collapse, see bug 366014
     setChildrenCollapsible(false);
 
@@ -78,6 +78,12 @@ KateViewManager::KateViewManager(QWidget *parentW, KateMainWindow *parent)
 
     // we want to trigger showing of the welcome view or a new document
     showWelcomeViewOrNewDocumentIfNeeded();
+
+    // enforce configured limit
+    readConfig();
+
+    // handle config changes
+    connect(KateApp::self(), &KateApp::configurationChanged, this, &KateViewManager::readConfig);
 }
 
 KateViewManager::~KateViewManager()
@@ -91,6 +97,13 @@ KateViewManager::~KateViewManager()
     }
 }
 
+void KateViewManager::readConfig()
+{
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KConfigGroup cgGeneral = KConfigGroup(config, "General");
+    m_sdiMode = cgGeneral.readEntry("SDI Mode", false);
+}
+
 void KateViewManager::setupActions()
 {
     /**
@@ -269,7 +282,7 @@ void KateViewManager::updateViewSpaceActions()
     goPrev->setEnabled(multipleViewSpaces);
 
     // only allow to split if we have a view that we could show in the new view space
-    const bool allowSplit = activeViewSpace() && activeViewSpace()->currentView();
+    const bool allowSplit = activeViewSpace();
     m_splitViewVert->setEnabled(allowSplit);
     m_splitViewHoriz->setEnabled(allowSplit);
 
@@ -281,7 +294,13 @@ void KateViewManager::updateViewSpaceActions()
 
 void KateViewManager::slotDocumentNew()
 {
-    createView();
+    // open new window for SDI case
+    if (m_sdiMode && !m_views.empty()) {
+        auto mainWindow = m_mainWindow->newWindow();
+        mainWindow->viewManager()->createView();
+    } else {
+        createView();
+    }
 }
 
 void KateViewManager::slotDocumentOpen()
@@ -409,26 +428,41 @@ KTextEditor::Document *KateViewManager::openUrls(const QList<QUrl> &urls, const
         }
     }
 
-    const std::vector<KTextEditor::Document *> docs = KateApp::self()->documentManager()->openUrls(urls, encoding, docInfo);
-    for (auto doc : docs) {
-        // forward to currently active view space
-        activeViewSpace()->registerDocument(doc);
-        connect(doc, &KTextEditor::Document::documentSavedOrUploaded, this, &KateViewManager::documentSavedOrUploaded);
-    }
-
-    // nothing opened => do nothing
+    // try to open all given files, early out if nothing done
+    auto docs = KateApp::self()->documentManager()->openUrls(urls, encoding, docInfo);
     if (docs.empty()) {
         return nullptr;
     }
 
-    // else, if we had some single untitled doc around, trigger close
+    bool first = true;
+    KTextEditor::Document *lastDocInThisViewManager = nullptr;
+    for (auto doc : docs) {
+        // it we have a doc to close, we can use this window for the first document even in SDI mode
+        if (!m_sdiMode || (first && docToClose) || m_views.empty()) {
+            // forward to currently active view space
+            activeViewSpace()->registerDocument(doc);
+            connect(doc, &KTextEditor::Document::documentSavedOrUploaded, this, &KateViewManager::documentSavedOrUploaded);
+            lastDocInThisViewManager = doc;
+            first = false;
+            continue;
+        }
+
+        // open new window for SDI case
+        auto mainWindow = m_mainWindow->newWindow();
+        mainWindow->viewManager()->openViewForDoc(doc);
+        first = false;
+    }
+
+    // if we had some single untitled doc around, trigger close
     // do this delayed to avoid havoc
     if (docToClose) {
         QTimer::singleShot(0, docToClose, [docToClose]() {
             KateApp::self()->documentManager()->closeDocument(docToClose);
         });
     }
-    return docs.back();
+
+    // return the last document we opened in this view manager if any
+    return lastDocInThisViewManager;
 }
 
 KTextEditor::View *KateViewManager::openUrlWithView(const QUrl &url, const QString &encoding)
@@ -567,9 +601,15 @@ void KateViewManager::documentsDeleted(const QList<KTextEditor::Document *> &)
      * ensure we don't end up with empty tabs in some view spaces
      * we did block view creation, re-trigger it
      */
+    auto viewspace = activeViewSpace();
     for (auto vs : m_viewSpaceList) {
-        vs->ensureViewForCurrentTab();
+        if (vs != viewspace) {
+            vs->ensureViewForCurrentTab();
+        }
     }
+    setActiveSpace(viewspace);
+    // Do it last for active view space so it remains active
+    activeViewSpace()->ensureViewForCurrentTab();
 
     /**
      * reactivate will ensure we really merge up the GUI again
@@ -653,7 +693,7 @@ KTextEditor::View *KateViewManager::createView(KTextEditor::Document *doc, KateV
         docInfo->startCursor = KTextEditor::Cursor::invalid(); // do this only once
 
         if (!doc->url().isLocalFile()) {
-            QSharedPointer<QMetaObject::Connection> conn(new QMetaObject::Connection());
+            std::shared_ptr<QMetaObject::Connection> conn(new QMetaObject::Connection());
             auto handler = [view, conn, c](KTextEditor::Document *) {
                 QObject::disconnect(*conn);
                 view->setCursorPosition(c);
@@ -787,6 +827,7 @@ void KateViewManager::activateView(KTextEditor::View *view)
             m_guiMergedView = nullptr;
         }
         Q_EMIT viewChanged(nullptr);
+        updateViewSpaceActions();
         return;
     }
 
@@ -840,11 +881,15 @@ void KateViewManager::activateView(KTextEditor::View *view)
 KTextEditor::View *KateViewManager::activateView(DocOrWidget docOrWidget, KateViewSpace *vs)
 {
     // activate existing view if possible
-    auto activeSpace = vs ? vs : activeViewSpace();
-    if (activeSpace->showView(docOrWidget)) {
-        // This will be null if currentView is not a KTE::View
-        activateView(activeSpace->currentView());
-        return activeView();
+    auto viewspace = vs ? vs : activeViewSpace();
+    if (viewspace->showView(docOrWidget)) {
+        // Only activateView if viewspace is active
+        if (viewspace == activeViewSpace()) {
+            // This will be null if currentView is not a KTE::View
+            activateView(viewspace->currentView());
+            return activeView();
+        }
+        return viewspace->currentView();
     }
 
     // create new view otherwise
@@ -1052,8 +1097,7 @@ void KateViewManager::splitViewSpace(KateViewSpace *vs, // = 0
 
     // if we have no current view, splitting makes ATM no sense, as we have
     // nothing to put into the new viewspace
-    auto v = vs->currentView();
-    if (!v) {
+    if (!vs->currentView() && !vs->currentWidget()) {
         return;
     }
 
@@ -1111,10 +1155,15 @@ void KateViewManager::splitViewSpace(KateViewSpace *vs, // = 0
     vsNew->setActive(true);
     vsNew->show();
 
-    createView(v->document());
-
     if (moveDocument) {
-        vs->closeDocument(v->document());
+        if (vs->currentWidget()) {
+            moveViewToViewSpace(vsNew, vs, vs->currentWidget());
+        } else {
+            moveViewToViewSpace(vsNew, vs, vs->currentView()->document());
+        }
+    } else {
+        auto v = vs->currentView();
+        createView(v ? v->document() : nullptr);
     }
 
     updateViewSpaceActions();
@@ -1646,10 +1695,11 @@ void KateViewManager::showWelcomeViewOrNewDocumentIfNeeded()
         // the user can decide: welcome page or a new untitled document for a new window?
         KSharedConfig::Ptr config = KSharedConfig::openConfig();
         KConfigGroup cgGeneral = KConfigGroup(config, "General");
-        if (cgGeneral.readEntry("Show welcome view for new window", true)) {
+        if (!m_welcomeViewAlreadyShown && cgGeneral.readEntry("Show welcome view for new window", true)) {
             showWelcomeView();
         } else {
-            slotDocumentNew();
+            // don't use slotDocumentNew() to avoid dummy new windows in SDI mode
+            createView();
         }
         triggerActiveViewFocus();
     });
@@ -1659,6 +1709,7 @@ void KateViewManager::showWelcomeView()
 {
     auto welcomeView = new WelcomeView(this);
     mainWindow()->addWidget(welcomeView);
+    m_welcomeViewAlreadyShown = true;
 }
 
 void KateViewManager::triggerActiveViewFocus()
