@@ -14,7 +14,6 @@
 #include "katefileactions.h"
 #include "katemainwindow.h"
 #include "katesessionmanager.h"
-#include "katetabbar.h"
 #include "kateupdatedisabler.h"
 #include "kateurlbar.h"
 #include "kateviewmanager.h"
@@ -327,6 +326,21 @@ KTextEditor::View *KateViewSpace::createView(KTextEditor::Document *doc)
         }
     }
 
+    {
+        // If this doc already has a view then the cursor position
+        // might be different from what is in config, try to
+        // restore position from one of the views
+        const auto views = doc->views();
+        if (views.size() > 1) {
+            for (auto view : views) {
+                if (view != v) {
+                    v->setCursorPosition(view->cursorPosition());
+                    break;
+                }
+            }
+        }
+    }
+
     connect(v, &KTextEditor::View::cursorPositionChanged, this, [this](KTextEditor::View *view, const KTextEditor::Cursor &newPosition) {
         if (view && view->document())
             addPositionToHistory(view->document()->url(), newPosition);
@@ -392,6 +406,22 @@ void KateViewSpace::removeView(KTextEditor::View *v)
     }
 }
 
+void KateViewSpace::saveViewConfig(KTextEditor::View *v)
+{
+    if (!v) {
+        return;
+    }
+    const auto url = v->document()->url();
+    if (!url.isEmpty() && !m_group.isEmpty()) {
+        const QString vgroup = QStringLiteral("%1 %2").arg(m_group, url.toString());
+        const KateSession::Ptr as = KateApp::self()->sessionManager()->activeSession();
+        if (as->config()) {
+            KConfigGroup viewGroup(as->config(), vgroup);
+            v->writeSessionConfig(viewGroup);
+        }
+    }
+}
+
 bool KateViewSpace::showView(DocOrWidget docOrWidget)
 {
     /**
@@ -540,6 +570,11 @@ void KateViewSpace::registerDocument(KTextEditor::Document *doc)
 
 void KateViewSpace::closeDocument(KTextEditor::Document *doc)
 {
+    auto it = m_docToView.find(doc);
+    if (it != m_docToView.end() && it->first) {
+        saveViewConfig(it->second);
+    }
+
     // If this is the only view of the document,
     // OR the doc has no views yet
     // just close the document and it will take
@@ -548,7 +583,6 @@ void KateViewSpace::closeDocument(KTextEditor::Document *doc)
         m_viewManager->slotDocumentClose(doc);
     } else {
         // KTE::view for this tab has been created yet?
-        auto it = m_docToView.find(doc);
         if (it != m_docToView.end()) {
             // - We have a view for this doc in this viewspace
             // - We have other views of this doc in other viewspaces
@@ -1009,10 +1043,7 @@ void KateViewSpace::showContextMenu(int idx, const QPoint &globalPos)
     QAction *compare = menu.addAction(i18n("Compare with Active Document"));
     compare->setIcon(QIcon::fromTheme(QStringLiteral("vcs-diff")));
     connect(compare, &QAction::triggered, this, [this, activeDocument, doc] {
-        auto w = new DiffWidget({}, this);
-        w->setWindowTitle(i18n("Diff %1 .. %2", activeDocument->documentName(), doc->documentName()));
-        w->diffDocs(activeDocument, doc);
-        m_viewManager->mainWindow()->addWidget(w);
+        DiffWidgetManager::diffDocs(activeDocument, doc, m_viewManager->mainWindow());
     });
 
     QMenu *compareUsing = new QMenu(i18n("Compare with Active Document Using"), &menu);
@@ -1087,7 +1118,7 @@ void KateViewSpace::showContextMenu(int idx, const QPoint &globalPos)
                                      QMessageBox::StandardButton::Ok);
         }
     } else if (choice == aDetachTab) {
-        auto mainWindow = KateApp::self()->newMainWindow();
+        auto mainWindow = viewManager()->mainWindow()->newWindow();
         mainWindow->viewManager()->openViewForDoc(doc);
 
         // use single shot as this action can trigger deletion of this viewspace!
